mysql.exceptions.server.Option_Prevents_Statement

Package mysql :: Package exceptions :: Module server :: Class Option_Prevents_Statement |
[hide private]
[frames] | no frames]

# Class Option_Prevents_Statement

source code

    exceptions.Exception --+
                           |
                  base.Error --+
                               |
                base.MySQL_Error --+
                                   |
                                  Option_Prevents_Statement

The MySQL server is running with the %s option so it cannot execute this statement

Instance Methods | [hide private]
Inherited from `base.MySQL_Error`: `__init__`, `__repr__`, `__str__` Inherited from `exceptions.Exception`: `__getitem__`

Instance Variables | [hide private]
Inherited from `base.MySQL_Error`: `errno`, `error_string`